; ##############################################################################
; ##############################################################################
; ##############################################################################
; WDTCSR  Watchdog Timer Control Register				
; WDIF WDIE WDP3 WDCE WDE WDP2 WDP1 WDP0				
; WDP3 WDP2 WDP1 WDP0 Time								
;	0 	0 	0 	0 	2K 	(2048) 	cycles 16 ms			
;	0 	0 	0 	1 	4K 	(4096) 	cycles 32 ms			
;	0 	0 	1 	0 	8K 	(8192) 	cycles 64 ms			
;	0 	0 	1 	1 	16K (16384) cycles 0.125 s			
;	0 	1 	0 	0 	32K (32768) cycles 0.25 s			
; 	0 	1 	0 	1 	64K (65536) cycles 0.5 s			
; *	0 	1 	1 	0 	128K (131072)cycles 1.0 s			
;	0 	1 	1 	1 	256K (262144)cycles 2.0 s			
;	1 	0 	0 	0 	512K (524288)cycles 4.0 s			
;	1 	0 	0 	1 	1024K(1048576)cycles 8.0 s			
; Wenn WDIE=1 dann wird zuerst die WDR-ISR aufgerufen 	
; und dann das System neu gestartet						
WDR_INITIALISIERUNG:
	WDR
	LDS TEMP, WDTCSR
	ori TEMP, (1<<WDCE) | (1<<WDE)
	STS WDTCSR, TEMP
	ldi temp, (1<<WDE)| (1<<WDIE)|(0<<WDP3)|(1<<WDP2)|(1<<WDP1)|(0<<WDP0)
	STS WDTCSR, TEMP
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MCUSR  MCU Status Register													
; 7,6,5,JTRF,WDRF,BORF,EXTRF,PORF												
; NEUSTART ber WDR, wenn BORF,EXTRF,PORF gestzt ist							
NEUSTART_MIT_WDR:
	in temp, MCUSR
	andi temp,0b00000111
	tst temp
	brne NEUSTART_MIT_WDR_FEHLER
	ret
NEUSTART_MIT_WDR_FEHLER:
	out MCUSR,NULL
	rjmp NEUSTART_MIT_WDR_FEHLER
; ##############################################################################
; ##############################################################################
; ##############################################################################
; Diese Routine wird bei WDR-Zeitberschreitung aufgerufen, hier knnte man		
; sich z.B. den Fehler anzeigen lasen, oder DATEN in den EEPROM schreiben		
WDT:
	WDR
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	call wait_100ms
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	call wait_100ms
	rjmp WDT
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
; SM2 	SM1 	SM0 Sleep Mode			
; 0 	0 		0 	Idle				
; 0 	0 		1 	ADC Noise Reduction	
; 0 	1 		0 	Power-down			
; 0 	1 		1 	Power-save			
; 1 	0 		0 	Reserved			
; 1 	0 		1 	Reserved			
; 1 	1 		0 	Standby(1)			
; 1 	1 		1 	Extended Standby(1)	
SLEEP_INITIALISIERUNG:
	ldi temp, (0<<SM2)| (0<<SM1)|(0<<SM0)|(1<<SE)
	out SMCR, temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SRAM_CLEAR:
	ldi ZL, LOW (SRAM_START)
	ldi ZH, HIGH(SRAM_START)
	ldi temp,0
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND-2)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND-2)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	breq SRAM_CLEAR_w		; gleich  => SPRUNG	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PROGRAMM_CHECK:
	; NULL		
	tst NULL
	brne PROGRAMM_CHECK_FEHLER
	; EINS		
	mov temp,EINS
	cpi temp,1
	brne PROGRAMM_CHECK_FEHLER
	; SRAM CHECK
	LDS temp,(adr_SRAM_CHECK)
	cpi temp,'S'
	brne PROGRAMM_CHECK_FEHLER
	ret
PROGRAMM_CHECK_FEHLER:
;	CLI											; INTERRUPTS sperren	
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN aus	
	sbi (LED_GELB_PORT),(LED_GELB_PIN_NR)		; GELB aus  
	call wait_100ms
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	call wait_100ms
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	rjmp PROGRAMM_CHECK_FEHLER
; ##############################################################################
; ##############################################################################
; ##############################################################################
LED_INITIALISIERUNG:
	; auf AUSGANG								
	sbi (LED_GRUEN_DDR),(LED_GRUEN_PIN_NR)		; GRN	
	sbi (LED_GELB_DDR),(LED_GELB_PIN_NR)		; GELB	
	sbi (LED_ROT_DDR),(LED_ROT_PIN_NR)			; ROT	
	; LED an									
	cbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN an   
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
LED_TEST:
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	

	cbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN an   
	call wait_100ms
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	call wait_100ms
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	call wait_100ms

	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STOP_UHR_START:
	STS(adr_STOP_UHR_ss10),NULL		; NULL
	STS(adr_STOP_UHR_ERGEBNIS),NULL	; NULL
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STOP_UHR_STOP:
	LDS temp,(adr_STOP_UHR_ss10)
	STS(adr_STOP_UHR_ERGEBNIS),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STOP_PROGRAMM:
	WDR
rjmp STOP_PROGRAMM
; ##############################################################################
; ##############################################################################
; ##############################################################################
MESSUNG_CPU_RECHEN_GESCHWINDIGKEIT:
	clr temp1
	clr temp2
	clr temp3
	clr temp4
	LDS R0,(adr_ss10)
MESSUNG_CPU_RECHEN_GESCHWINDIGKEIT_s1:
	WDR
	LDS R1,(adr_ss10)
	cp R0,R1
	breq MESSUNG_CPU_RECHEN_GESCHWINDIGKEIT_s1
MESSUNG_CPU_RECHEN_GESCHWINDIGKEIT_s2:
	add temp1,EINS
	adc temp2,NULL
	adc temp3,NULL
	adc temp4,NULL
	LDS R0,(adr_ss10)
	cp R0,R1
	breq MESSUNG_CPU_RECHEN_GESCHWINDIGKEIT_s2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
